from setuptools import setup, find_packages

setup(
    name = "revolution.py",
    version = "5.0.0.3",
    description = "A simple Py package to integrate Revolution's bot API into python.",
    long_description = "A simple Py package to integrate Revolution's bot API into Python. \nhttps://github.com/JustAnEric/Revolution.py",
    author = "JustAnEric",
    maintainer = "Revolution Corporation",
    requires = ["requests"],
    url = "https://revolution.ericplayzyt.repl.co/",
    packages = find_packages(),
    keywords = ["revolutionpy", "python3", "revolution"]
)